Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(289)

Unified Diff: content/renderer/render_widget.h

Issue 2605743002: Use consistent types for ICC profiles (Closed)
Patch Set: No export for static lib Created 4 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/render_widget.h
diff --git a/content/renderer/render_widget.h b/content/renderer/render_widget.h
index 76bcebaed022f37c9f0d1281470aeb683818e08c..303aed11f6138e5d0e18cd089df4bbc2c59fa3b6 100644
--- a/content/renderer/render_widget.h
+++ b/content/renderer/render_widget.h
@@ -384,8 +384,8 @@ class CONTENT_EXPORT RenderWidget
// the browser even if the composition info is not changed.
void UpdateCompositionInfo(bool immediate_request);
- // Change the device ICC color profile while running a layout test.
- void SetDeviceColorProfileForTesting(const std::vector<char>& color_profile);
+ // Change the device color space while running a layout test.
+ void SetDeviceColorSpaceForTesting(const gfx::ColorSpace& color_space);
// Called when the Widget has changed size as a result of an auto-resize.
void DidAutoResize(const gfx::Size& new_size);
@@ -544,7 +544,6 @@ class CONTENT_EXPORT RenderWidget
void AutoResizeCompositor();
virtual void OnSetDeviceScaleFactor(float device_scale_factor);
- bool SetDeviceColorProfile(const std::vector<char>& color_profile);
virtual void OnOrientationChange();
@@ -742,9 +741,6 @@ class CONTENT_EXPORT RenderWidget
// |screen_info_| on some platforms, and defaults to 1 on other platforms.
float device_scale_factor_;
- // The device color profile on supported platforms.
- std::vector<char> device_color_profile_;
-
// State associated with synthetic gestures. Synthetic gestures are processed
// in-order, so a queue is sufficient to identify the correct state for a
// completed gesture.

Powered by Google App Engine
This is Rietveld 408576698